# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2017-06-13 13:29
from __future__ import unicode_literals

from django.db import migrations
import nodeconductor.core.fields


class Migration(migrations.Migration):

    dependencies = [
        ('nodeconductor_saml2', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='identityprovider',
            name='metadata',
            field=nodeconductor.core.fields.JSONField(default={}),
        ),
    ]
